@@ -1,6 +1,7 @@
 /*
 MyServer
-Copyright (C) 2002, 2003, 2004, 2008, 2009 Free Software Foundation, Inc.
+Copyright (C) 2002, 2003, 2004, 2008, 2009, 2010 Free Software
+Foundation, Inc.
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 3 of the License, or
@@ -15,7 +16,7 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "stdafx.h"
+#include "myserver.h"
 #include <include/base/base64/mime_utils.h>
 
 extern "C"
@@ -392,7 +393,7 @@ char* CBase64Utils::encode (const char *input, int bufsize)
 char* CBase64Utils::decode (const char *input, int *bufsize)
 {
   int std = 0, count = 1, resultlen = 0;
-  char *finalresult = (char*)calloc (*bufsize + sizeof (char), sizeof (char));
+  char *finalresult = new char[*bufsize + sizeof (char)];
 
   const char *s = input;
   char *result = finalresult;
@@ -471,8 +472,7 @@ CQPUtils::~CQPUtils ()
 char* CQPUtils::decode (char *input)
 {
   char *s = input;
-  char *finalresult = (char*)calloc (strlen (input) + sizeof (char),
-                                    sizeof (char));
+  char *finalresult = new char [strlen (input) + sizeof (char)];
   char *result = finalresult;
   while (*s != '\0')
   {
