@@ -1,6 +1,7 @@
 /*
 MyServer
-Copyright (C) 2002, 2003, 2004, 2008, 2009 Free Software Foundation, Inc.
+Copyright (C) 2002, 2003, 2004, 2008, 2009, 2010 Free Software
+Foundation, Inc.
 Copyright (C) 2004, Guinet Adrien (grainailleur)
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -16,7 +17,7 @@ You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "stdafx.h"
+#include "myserver.h"
 #include <include/base/mem_buff/mem_buff.h>
 #include <include/base/crypt/md5.h>
 
