@@ -1,6 +1,7 @@
 /*
   MyServer
-  Copyright (C) 2005, 2007, 2008, 2009 Free Software Foundation, Inc.
+  Copyright (C) 2005, 2007, 2008, 2009, 2010 Free Software Foundation,
+  Inc.
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
@@ -15,7 +16,7 @@
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "stdafx.h"
+#include "myserver.h"
 
 #include <include/protocol/http/dyn_http_manager.h>
 #include <include/base/xml/xml_parser.h>
